@@ -1,8 +1,8 @@
 package Bundle::HTTP::WebTest;
 
-# $Id: WebTest.pm,v 1.7 2002/12/14 16:55:16 m_ilya Exp $
+# $Id: WebTest.pm,v 1.9 2003/03/02 11:52:10 m_ilya Exp $
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 =head1 NAME
 
@@ -36,7 +36,7 @@ Pod::Man
 
 Time::HiRes
 
-Test::Builder
+Test::More
 
 Test::Builder::Tester - only required to run C<make test>
 
@@ -44,14 +44,14 @@ URI
 
 =head1 DESCRIPTION
 
-This bundle includes all modules required to run
-L<HTTP::WebTest|HTTP::WebTest> using all bundled plugins. Also it
+This bundle includes all modules required to use
+L<HTTP::WebTest|HTTP::WebTest> with all its standart plugins. Also it
 includes all modules required to run test suite for
 L<HTTP::WebTest|HTTP::WebTest>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 Ilya Martynov.  All rights reserved.
+Copyright (c) 2002-2003 Ilya Martynov.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
